/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.web.actions;

import org.wso2.registry.secure.SecureRegistry;
import org.wso2.registry.secure.RegistryUserManager;
import org.wso2.registry.ActionConstants;
import com.opensymphony.xwork2.ActionSupport;

public class AuthorizationAction extends AbstractRegistryAction {

    private String pathToAuthorize;
    private String userToAuthorize;

    private boolean get;
    private boolean put;
    private boolean delete;

    public String execute() throws Exception {

        SecureRegistry secureRegistry = (SecureRegistry) getRegistry();
        RegistryUserManager userManager = secureRegistry.getUserManager();

        if (get) {
            userManager.authorizeUser(userToAuthorize, pathToAuthorize, ActionConstants.GET);
        } else {
            userManager.denyUser(userToAuthorize, pathToAuthorize, ActionConstants.GET);
        }

        if (put) {
            userManager.authorizeUser(userToAuthorize, pathToAuthorize, ActionConstants.PUT);
        } else {
            userManager.denyUser(userToAuthorize, pathToAuthorize, ActionConstants.PUT);
        }

        if (delete) {
            userManager.authorizeUser(userToAuthorize, pathToAuthorize, ActionConstants.DELETE);
        } else {
            userManager.denyUser(userToAuthorize, pathToAuthorize, ActionConstants.DELETE);
        }
        
        return ActionSupport.SUCCESS;
    }

    public String getPathToAuthorize() {
        return pathToAuthorize;
    }

    public void setPathToAuthorize(String pathToAuthorize) {

        // we are handling only the current version in the human view
        if (pathToAuthorize.indexOf("?") > 0) {
            pathToAuthorize = pathToAuthorize.split("\\?")[0];
        }

        this.pathToAuthorize = pathToAuthorize;
    }

    public String getUserToAuthorize() {
        return userToAuthorize;
    }

    public void setUserToAuthorize(String userToAuthorize) {
        this.userToAuthorize = userToAuthorize;
    }

    public boolean isGet() {
        return get;
    }

    public void setGet(boolean get) {
        this.get = get;
    }

    public boolean isPut() {
        return put;
    }

    public void setPut(boolean put) {
        this.put = put;
    }

    public boolean isDelete() {
        return delete;
    }

    public void setDelete(boolean delete) {
        this.delete = delete;
    }
}
